# Postal Service Python Backend
[![Mercari](https://github.com/apmnt/postalservice_python/actions/workflows/mercari_tests.yml/badge.svg)](https://github.com/apmnt/postalservice_python/actions/workflows/mercari_tests.yml)
[![Fril](https://github.com/apmnt/postalservice_python/actions/workflows/fril_tests.yml/badge.svg)](https://github.com/apmnt/postalservice_python/actions/workflows/fril_tests.yml)